// Project Sword & Gun Copyright © 2021 Kevin Poretti

#pragma once

#include "CoreMinimal.h"
#include "GameFramework/Character.h"
#include "SNGCharacterBase.generated.h"

class USpringArmComponent;
class UCameraComponent;

UCLASS()
class SWORDNGUN_API ASNGCharacterBase : public ACharacter
{
	GENERATED_BODY()

public:
	// Sets default values for this character's properties
	ASNGCharacterBase(const FObjectInitializer& ObjectInitializer);

protected:
	UPROPERTY(VisibleAnywhere, BlueprintReadOnly, Category="Components")
	UCameraComponent* CameraComponent;

	UPROPERTY(VisibleAnywhere, BlueprintReadOnly, Category="Components")
	USpringArmComponent* SpringArmComponent;

	UPROPERTY(BlueprintReadOnly)
	FVector2D InputDirection;

	UPROPERTY(EditAnywhere, BlueprintReadOnly, Category="Animations")
	UAnimMontage* JumpNeutralMontage;
	
	UPROPERTY(EditAnywhere, BlueprintReadOnly, Category="Animations")
	UAnimMontage* JumpFwdMontage;

	UPROPERTY(EditAnywhere, BlueprintReadOnly, Category="Animations")
	UAnimMontage* JumpBackMontage;

	UPROPERTY(BlueprintReadWrite)
	bool CanMove;

	UPROPERTY(BlueprintReadWrite)
	bool CanMovementCancelMontage;
	
	void MoveForward(float Value);

	void MoveRight(float Value);

	void StartJump();

	virtual void Landed(const FHitResult& Hit) override;
	
	// Called when the game starts or when spawned
	virtual void BeginPlay() override;

	FVector GetInputAsWorldDirection();
	
public:	
	// Called every frame
	virtual void Tick(float DeltaTime) override;

	// Called to bind functionality to input
	virtual void SetupPlayerInputComponent(class UInputComponent* PlayerInputComponent) override;
	
};
